@@ -13,4 +13,9 @@ SQLITE_THREADS = cpu_count()
 SQLITE_TIMEOUT = 5
 REDIS_TIMEOUT = 5
 CACHE_GRACE = 60
+PROACTIVE_FETCH_ENABLED = False
+PROACTIVE_FETCH_INTERVAL = 86400
+PROACTIVE_FETCH_CONCURRENCY_LIMIT = 100
+PROACTIVE_FETCH_GRACE_RATIO = 2.0
 USER_AGENT = "postfix-mta-sts-resolver"
+REQUIRE_SNI = True
